@@ -14,11 +14,15 @@ build_time_vars = {'ABIFLAGS': 'm',
  'BASECFLAGS': '-Wno-unused-result -Wsign-compare',
  'BASECPPFLAGS': '',
  'BASEMODLIBS': '',
- 'BINDIR': '/opt/lib/python-3.5.2/bin',
- 'BINLIBDEST': '/opt/lib/python-3.5.2/lib/python3.5',
+ 'BINDIR': '/opt/lib/python-3.5.3/bin',
+ 'BINLIBDEST': '/opt/lib/python-3.5.3/lib/python3.5',
  'BLDLIBRARY': 'libpython3.5m.a',
- 'BLDSHARED': 'gcc -pthread -shared -L/opt/lib/bz2/lib -L/opt/lib/lzma/lib '
-              '-L/opt/lib/ssl/lib -Wl,--version-script=python.map',
+ 'BLDSHARED': 'gcc -pthread -shared -L/opt/lib/bz2/lib     '
+              '-L/opt/lib/lzma/lib     -L/opt/lib/ssl/lib     '
+              '-L/opt/lib/zlib/lib     -L/opt/lib/libc6/lib     '
+              '-L/opt/lib/ncurses/lib     -L/opt/lib/gpm/lib     '
+              '-L/opt/lib/sqlite/lib     -L/opt/lib/readline/lib     '
+              '-Wl,--version-script=python.map',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
  'BUILD_GNU_TYPE': 'i686-pc-linux-gnu',
@@ -34,29 +38,36 @@ build_time_vars = {'ABIFLAGS': 'm',
  'CONFIGURE_CFLAGS': '',
  'CONFIGURE_CFLAGS_NODIST': '-Werror=declaration-after-statement',
  'CONFIGURE_CPPFLAGS': '',
- 'CONFIGURE_LDFLAGS': '-L/opt/lib/bz2/lib -L/opt/lib/lzma/lib '
-                      '-L/opt/lib/ssl/lib -Wl,--version-script=python.map',
- 'CONFIG_ARGS': "'--prefix=/opt/lib/python-3.5.2' '--enable-ipv6' "
+ 'CONFIGURE_LDFLAGS': '-L/opt/lib/bz2/lib     -L/opt/lib/lzma/lib     '
+                      '-L/opt/lib/ssl/lib     -L/opt/lib/zlib/lib     '
+                      '-L/opt/lib/libc6/lib     -L/opt/lib/ncurses/lib     '
+                      '-L/opt/lib/gpm/lib     -L/opt/lib/sqlite/lib     '
+                      '-L/opt/lib/readline/lib     '
+                      '-Wl,--version-script=python.map',
+ 'CONFIG_ARGS': "'--prefix=/opt/lib/python-3.5.3' '--enable-ipv6' "
                 "'--enable-loadable-sqlite-extensions' "
-                "'--with-dbmliborder=bdb' '--with-wide-unicode' "
-                "'--with-computed-gotos' '--with-pymalloc' "
-                "'LDFLAGS=-L/opt/lib/bz2/lib -L/opt/lib/lzma/lib "
-                "-L/opt/lib/ssl/lib -Wl,--version-script=python.map'",
- 'CONFINCLUDEDIR': '/opt/lib/python-3.5.2/include',
- 'CONFINCLUDEPY': '/opt/lib/python-3.5.2/include/python3.5m',
+                "'--with-dbmliborder=bdb' '--with-computed-gotos' "
+                "'--with-pymalloc' 'LDFLAGS=    -L/opt/lib/bz2/lib     "
+                '-L/opt/lib/lzma/lib     -L/opt/lib/ssl/lib     '
+                '-L/opt/lib/zlib/lib     -L/opt/lib/libc6/lib     '
+                '-L/opt/lib/ncurses/lib     -L/opt/lib/gpm/lib     '
+                '-L/opt/lib/sqlite/lib     -L/opt/lib/readline/lib     '
+                "-Wl,--version-script=python.map'",
+ 'CONFINCLUDEDIR': '/opt/lib/python-3.5.3/include',
+ 'CONFINCLUDEPY': '/opt/lib/python-3.5.3/include/python3.5m',
  'COREPYTHONPATH': ':plat-linux',
- 'COVERAGE_INFO': '/home/sources/packages/Python-3.5.2/coverage.info',
- 'COVERAGE_REPORT': '/home/sources/packages/Python-3.5.2/lcov-report',
+ 'COVERAGE_INFO': '/home/sources/packages/Python-3.5.3/coverage.info',
+ 'COVERAGE_REPORT': '/home/sources/packages/Python-3.5.3/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
- 'CPPFLAGS': '-I. -IInclude -I./Include',
+ 'CPPFLAGS': '-I. -I./Include',
  'CXX': 'g++ -pthread',
- 'DESTDIRS': '/opt/lib/python-3.5.2 /opt/lib/python-3.5.2/lib '
-             '/opt/lib/python-3.5.2/lib/python3.5 '
-             '/opt/lib/python-3.5.2/lib/python3.5/lib-dynload',
- 'DESTLIB': '/opt/lib/python-3.5.2/lib/python3.5',
+ 'DESTDIRS': '/opt/lib/python-3.5.3 /opt/lib/python-3.5.3/lib '
+             '/opt/lib/python-3.5.3/lib/python3.5 '
+             '/opt/lib/python-3.5.3/lib/python3.5/lib-dynload',
+ 'DESTLIB': '/opt/lib/python-3.5.3/lib/python3.5',
  'DESTPATH': '',
- 'DESTSHARED': '/opt/lib/python-3.5.2/lib/python3.5/lib-dynload',
+ 'DESTSHARED': '/opt/lib/python-3.5.3/lib/python3.5/lib-dynload',
  'DIRMODE': 755,
  'DIST': 'README ChangeLog configure configure.ac acconfig.h pyconfig.h.in '
          'Makefile.pre.in Include Lib Misc Ext-dummy',
@@ -301,7 +312,6 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_PTY_H': 1,
  'HAVE_PUTENV': 1,
  'HAVE_PWRITE': 1,
- 'HAVE_RAND_EGD': 1,
  'HAVE_READLINK': 1,
  'HAVE_READLINKAT': 1,
  'HAVE_READV': 1,
@@ -404,6 +414,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_SYS_NDIR_H': 0,
  'HAVE_SYS_PARAM_H': 1,
  'HAVE_SYS_POLL_H': 1,
+ 'HAVE_SYS_RANDOM_H': 0,
  'HAVE_SYS_RESOURCE_H': 1,
  'HAVE_SYS_SELECT_H': 1,
  'HAVE_SYS_SENDFILE_H': 1,
@@ -465,12 +476,12 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HGTAG': '',
  'HGVERSION': '',
  'HOST_GNU_TYPE': 'i686-pc-linux-gnu',
- 'INCLDIRSTOMAKE': '/opt/lib/python-3.5.2/include '
-                   '/opt/lib/python-3.5.2/include '
-                   '/opt/lib/python-3.5.2/include/python3.5m '
-                   '/opt/lib/python-3.5.2/include/python3.5m',
- 'INCLUDEDIR': '/opt/lib/python-3.5.2/include',
- 'INCLUDEPY': '/opt/lib/python-3.5.2/include/python3.5m',
+ 'INCLDIRSTOMAKE': '/opt/lib/python-3.5.3/include '
+                   '/opt/lib/python-3.5.3/include '
+                   '/opt/lib/python-3.5.3/include/python3.5m '
+                   '/opt/lib/python-3.5.3/include/python3.5m',
+ 'INCLUDEDIR': '/opt/lib/python-3.5.3/include',
+ 'INCLUDEPY': '/opt/lib/python-3.5.3/include/python3.5m',
  'INSTALL': '/usr/bin/install -c',
  'INSTALL_DATA': '/usr/bin/install -c -m 644',
  'INSTALL_PROGRAM': '/usr/bin/install -c',
@@ -480,23 +491,30 @@ build_time_vars = {'ABIFLAGS': 'm',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
  'LDCXXSHARED': 'g++ -pthread -shared',
- 'LDFLAGS': '-L/opt/lib/bz2/lib -L/opt/lib/lzma/lib -L/opt/lib/ssl/lib '
-            '-Wl,--version-script=python.map',
+ 'LDFLAGS': '-L/opt/lib/bz2/lib     -L/opt/lib/lzma/lib     '
+            '-L/opt/lib/ssl/lib     -L/opt/lib/zlib/lib     '
+            '-L/opt/lib/libc6/lib     -L/opt/lib/ncurses/lib     '
+            '-L/opt/lib/gpm/lib     -L/opt/lib/sqlite/lib     '
+            '-L/opt/lib/readline/lib     -Wl,--version-script=python.map',
  'LDLAST': '',
  'LDLIBRARY': 'libpython3.5m.a',
  'LDLIBRARYDIR': '',
- 'LDSHARED': 'gcc -pthread -shared -L/opt/lib/bz2/lib -L/opt/lib/lzma/lib '
-             '-L/opt/lib/ssl/lib -Wl,--version-script=python.map',
+ 'LDSHARED': 'gcc -pthread -shared -L/opt/lib/bz2/lib     '
+             '-L/opt/lib/lzma/lib     -L/opt/lib/ssl/lib     '
+             '-L/opt/lib/zlib/lib     -L/opt/lib/libc6/lib     '
+             '-L/opt/lib/ncurses/lib     -L/opt/lib/gpm/lib     '
+             '-L/opt/lib/sqlite/lib     -L/opt/lib/readline/lib     '
+             '-Wl,--version-script=python.map',
  'LDVERSION': '3.5m',
  'LIBC': '',
- 'LIBDEST': '/opt/lib/python-3.5.2/lib/python3.5',
- 'LIBDIR': '/opt/lib/python-3.5.2/lib',
+ 'LIBDEST': '/opt/lib/python-3.5.3/lib/python3.5',
+ 'LIBDIR': '/opt/lib/python-3.5.3/lib',
  'LIBFFI_INCLUDEDIR': '',
  'LIBM': '-lm',
  'LIBOBJDIR': 'Python/',
  'LIBOBJS': '',
- 'LIBPC': '/opt/lib/python-3.5.2/lib/pkgconfig',
- 'LIBPL': '/opt/lib/python-3.5.2/lib/python3.5/config-3.5m',
+ 'LIBPC': '/opt/lib/python-3.5.3/lib/pkgconfig',
+ 'LIBPL': '/opt/lib/python-3.5.3/lib/python3.5/config-3.5m',
  'LIBRARY': 'libpython3.5m.a',
  'LIBRARY_OBJS': '\\',
  'LIBRARY_OBJS_OMIT_FROZEN': '\\',
@@ -515,15 +533,18 @@ build_time_vars = {'ABIFLAGS': 'm',
  'MACHDEPPATH': ':plat-linux',
  'MACHDEPS': 'plat-linux',
  'MACHDEP_OBJS': '',
- 'MACHDESTLIB': '/opt/lib/python-3.5.2/lib/python3.5',
+ 'MACHDESTLIB': '/opt/lib/python-3.5.3/lib/python3.5',
  'MACOSX_DEPLOYMENT_TARGET': '',
  'MAINCC': 'gcc -pthread',
  'MAJOR_IN_MKDEV': 0,
  'MAJOR_IN_SYSMACROS': 0,
  'MAKESETUP': './Modules/makesetup',
- 'MANDIR': '/opt/lib/python-3.5.2/share/man',
+ 'MANDIR': '/opt/lib/python-3.5.3/share/man',
  'MKDIR_P': '/bin/mkdir -p',
  'MODLIBS': '',
+ 'MODNAMES': '_thread _signal posix errno pwd _sre _codecs _weakref _functools '
+             '_operator _collections itertools atexit _stat time _locale _io '
+             'zipimport faulthandler _tracemalloc _symtable xxsubtype',
  'MODOBJS': 'Modules/_threadmodule.o  Modules/signalmodule.o  '
             'Modules/posixmodule.o  Modules/errnomodule.o  '
             'Modules/pwdmodule.o  Modules/_sre.o  Modules/_codecsmodule.o  '
@@ -546,8 +567,8 @@ build_time_vars = {'ABIFLAGS': 'm',
  'OPCODETARGETS_H': '\\',
  'OPCODE_H': './Include/opcode.h',
  'OPCODE_H_DIR': './Include',
- 'OPCODE_H_GEN': 'python3  ./Tools/scripts/generate_opcode_h.py '
-                 './Lib/opcode.py ./Include/opcode.h',
+ 'OPCODE_H_GEN': 'python3 ./Tools/scripts/generate_opcode_h.py ./Lib/opcode.py '
+                 './Include/opcode.h',
  'OPCODE_H_SCRIPT': './Tools/scripts/generate_opcode_h.py',
  'OPT': '-DNDEBUG -g -fwrapv -O3 -Wall -Wstrict-prototypes',
  'OTHER_LIBTOOL_OPT': '',
@@ -585,6 +606,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'PYTHONFRAMEWORKPREFIX': '',
  'PYTHONPATH': ':plat-linux',
  'PYTHON_FOR_BUILD': './python -E',
+ 'PYTHON_FOR_GEN': 'python3',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
  'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 -Wall '
@@ -592,13 +614,16 @@ build_time_vars = {'ABIFLAGS': 'm',
  'PY_CFLAGS_NODIST': '-Werror=declaration-after-statement',
  'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 '
                    '-Wall -Wstrict-prototypes '
-                   '-Werror=declaration-after-statement -I. -IInclude '
-                   '-I./Include  -DPy_BUILD_CORE',
- 'PY_CPPFLAGS': '-I. -IInclude -I./Include',
+                   '-Werror=declaration-after-statement -I. -I./Include  '
+                   '-DPy_BUILD_CORE',
+ 'PY_CPPFLAGS': '-I. -I./Include',
  'PY_FORMAT_LONG_LONG': '"ll"',
  'PY_FORMAT_SIZE_T': '"z"',
- 'PY_LDFLAGS': '-L/opt/lib/bz2/lib -L/opt/lib/lzma/lib -L/opt/lib/ssl/lib '
-               '-Wl,--version-script=python.map',
+ 'PY_LDFLAGS': '-L/opt/lib/bz2/lib     -L/opt/lib/lzma/lib     '
+               '-L/opt/lib/ssl/lib     -L/opt/lib/zlib/lib     '
+               '-L/opt/lib/libc6/lib     -L/opt/lib/ncurses/lib     '
+               '-L/opt/lib/gpm/lib     -L/opt/lib/sqlite/lib     '
+               '-L/opt/lib/readline/lib     -Wl,--version-script=python.map',
  'Py_DEBUG': 0,
  'Py_ENABLE_SHARED': 0,
  'Py_HASH_ALGORITHM': 0,
@@ -608,7 +633,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
  'RUNSHARED': '',
- 'SCRIPTDIR': '/opt/lib/python-3.5.2/lib',
+ 'SCRIPTDIR': '/opt/lib/python-3.5.3/lib',
  'SETPGRP_HAVE_ARG': 0,
  'SGI_ABI': '',
  'SHELL': '/bin/sh',
@@ -675,10 +700,9 @@ build_time_vars = {'ABIFLAGS': 'm',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 1,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/home/sources/packages/Python-3.5.2',
- 'abs_srcdir': '/home/sources/packages/Python-3.5.2',
- 'cross_compiling': 'no',
- 'datarootdir': '/opt/lib/python-3.5.2/share',
- 'exec_prefix': '/opt/lib/python-3.5.2',
- 'prefix': '/opt/lib/python-3.5.2',
+ 'abs_builddir': '/home/sources/packages/Python-3.5.3',
+ 'abs_srcdir': '/home/sources/packages/Python-3.5.3',
+ 'datarootdir': '/opt/lib/python-3.5.3/share',
+ 'exec_prefix': '/opt/lib/python-3.5.3',
+ 'prefix': '/opt/lib/python-3.5.3',
  'srcdir': '.'}
